@@ -362,7 +362,14 @@ write_group_data (group_t *data, int is_locked)
 	  /* Open a temp group file */
 	  newgf_fd = mkstemp (group_tmp);
 #ifdef WITH_SELINUX
-	  restore_default_context (prev_context);
+          if (restore_default_context (prev_context) < 0)
+	    {
+	      if (newgf_fd >= 0)
+		close (newgf_fd);
+	      fclose (oldgf);
+	      retval = -1;
+	      goto error_group;
+	    }
 #endif
 	  if (newgf_fd == -1)
 	    {
@@ -666,12 +673,12 @@ write_group_data (group_t *data, int is_locked)
 #endif
   else if (data->service == S_YP)
     {
-      fprintf (stderr, _("Cannot modify/add NIS group entries\n"));
+      fprintf (stderr, _("Cannot modify/add NIS group entries.\n"));
       retval = -1;
     }
   else
     {
-      fprintf (stderr, _("Unknown service %d\n"), data->service);
+      fprintf (stderr, _("Unknown service %d.\n"), data->service);
       retval = -1;
     }
 
