@@ -101,5 +101,13 @@ extern struct logfunc_t *logfunc_list;
 #define MSG_INACTIVE_DAYS_CHANGED 60 /* account, id, inactive days, old value, caller id */
 #define MSG_EXPIRE_DATE_CHANGED 61 /* account, id, expire date, old date, caller id */
 #define MSG_DROP_PRIVILEGE_FAILED 62 /* errno, caller id */
+#define MSG_MAIL_FILE_CREATED 63 /* account, caller id */
+#define MSG_MINIMUM_AGE 64 /* account, uid, min, old min, caller id */
+#define MSG_MAXIMUM_AGE 65 /* account, uid, max, old max, caller id */
+#define MSG_WARNING_DAYS 66 /* account, uid, warn, old warn, caller id */
+#define MSG_INACTIVE_DAYS 67 /* account, uid, inactive, old inactive, caller id */
+#define MSG_LAST_CHANGE_DATE 68 /* account, uid, change, old change, caller id */
+#define MSG_EXPIRE_DATE 69 /* account, uid, expire, old expire, caller id */
+#define MSG_STDIN_FOR_NONROOT_DENIED 70 /* caller id */
 
 #endif
