@@ -346,7 +346,7 @@ update_npd (nis_object *obj, user_t *data)
       return -1;
     }
   request.user_pub_key.user_pub_key_len = HEXKEYBYTES;
-  request.user_pub_key.user_pub_key_val = pkey_user;
+  request.user_pub_key.user_pub_key_val = (unsigned char *) pkey_user;
   /* get publickey of the server running rpc.nispasswdd. For that,
      we have to find the name of the master server for the user domain. */
   server = nis_getservlist (request.domain);
@@ -386,7 +386,7 @@ update_npd (nis_object *obj, user_t *data)
       return -1;
     }
   request.npd_authpass.npd_authpass_len = 16;
-  request.npd_authpass.npd_authpass_val = oldpwd;
+  request.npd_authpass.npd_authpass_val = (unsigned char *) oldpwd;
 
   /* Try to authenticate us and the server.
      XXX This should be done in a loop,
