@@ -114,23 +114,26 @@ set_default_context (const char *filename, char **prev_context)
 int
 restore_default_context (security_context_t prev_context)
 {
-  if (is_selinux_enabled () <= 0)
-    return 0;
+  int retval = 0;
 
-  if (setfscreatecon (prev_context) < 0 )
+  if (is_selinux_enabled () > 0)
     {
-      fprintf (stderr,
-	       _("Couldn't reset default security context to `%s': %s\n"),
-	       prev_context, strerror (errno));
+      if (setfscreatecon (prev_context) < 0 )
+	{
+	  fprintf (stderr,
+		   _("Couldn't reset default security context to `%s': %s\n"),
+		   prev_context, strerror (errno));
+	  retval = -1;
+	}
+
+      if (prev_context)
+	{
+	  freecon (prev_context);
+	  prev_context = NULL;
+	}
     }
 
-  if (prev_context)
-    {
-      freecon (prev_context);
-      prev_context = NULL;
-    }
-
-  return 0;
+  return retval;
 }
 
 #endif
