@@ -468,7 +468,14 @@ write_user_data (user_t *data, int is_locked)
 	  /* Open a temp passwd file */
 	  newpf_fd = mkstemp (passwd_tmp);
 #ifdef WITH_SELINUX
-          restore_default_context (prev_context);
+          if (restore_default_context (prev_context) < 0)
+	    {
+	      if (newpf_fd >= 0)
+		close (newpf_fd);
+              fclose (oldpf);
+              retval = -1;
+              goto error_passwd;
+	    }
 #endif
 	  if (newpf_fd == -1)
 	    {
@@ -700,7 +707,14 @@ write_user_data (user_t *data, int is_locked)
           /* Open a temp shadow file */
           newpf_fd = mkstemp (shadow_tmp);
 #ifdef WITH_SELINUX
-          restore_default_context (prev_context);
+          if (restore_default_context (prev_context) < 0)
+	    {
+	      if (newpf_fd >= 0)
+		close (newpf_fd);
+              fclose (oldpf);
+              retval = -1;
+              goto error_shadow;
+	    }
 #endif
           if (newpf_fd == -1)
             {
@@ -1045,7 +1059,7 @@ Error while closing temporary shadow file: %m\n"));
 #endif
   else
     {
-      fprintf (stderr, _("Unknown service %d\n"), data->service);
+      fprintf (stderr, _("Unknown service %d.\n"), data->service);
       retval = -1;
     }
 
