@@ -1,4 +1,4 @@
-/* Copyright (C) 2003, 2004 Thorsten Kukuk
+/* Copyright (C) 2003, 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
-#include <syslog.h>
 #include <getopt.h>
 #include <locale.h>
 #include <libintl.h>
@@ -43,6 +42,7 @@
 #endif
 
 #include "public.h"
+#include "logging.h"
 #include "logindefs.h"
 #include "read-files.h"
 #include "error_codes.h"
@@ -106,7 +106,7 @@ main (int argc, char *argv[])
   bindtextdomain(PACKAGE, LOCALEDIR);
   textdomain(PACKAGE);
 
-  openlog (program, LOG_PID, LOG_AUTHPRIV);
+  open_sec_log (program);
 
   use_crypt = parse_crypt_arg (getlogindefs_str ("CRYPT", "des"));
 
@@ -178,7 +178,7 @@ main (int argc, char *argv[])
           print_help (program);
           return 0;
         case 'v':
-          print_version (program, "2004");
+          print_version (program, "2005");
           return 0;
         case 'u':
           print_usage (stdout, program);
