@@ -253,7 +253,13 @@ loop_over_group_file (int quiet)
   /* Open a temp group file */
   output_fd = mkstemp (outputname);
 #ifdef WITH_SELINUX
-  restore_default_context (prev_context);
+  if (restore_default_context (prev_context) < 0)
+    {
+      if (output_fd >= 0)
+	close (output_fd);
+      fclose (input);
+      return E_FAILURE;
+    }
 #endif
   if (output_fd == -1)
     {
@@ -621,7 +627,14 @@ sort_group_file (void)
   /* Open a temp group file */
   newgf_fd = mkstemp (group_tmp);
 #ifdef WITH_SELINUX
-  restore_default_context (prev_context);
+  if (restore_default_context (prev_context) < 0)
+    {
+      if (newgf_fd >= 0)
+	close (newgf_fd);
+      fclose (oldgf);
+      retval = -1;
+      goto error_group;
+    }
 #endif
   if (newgf_fd == -1)
     {
