@@ -42,6 +42,7 @@
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdarg.h>
 #include <unistd.h>
 #include <pwd.h>
 #include <shadow.h>
@@ -52,11 +53,15 @@
 #include <sys/time.h>
 #include <rpc/types.h>
 
+#ifdef USE_GNUTLS
+#include <gnutls/gnutls.h>
+#else
 #include <openssl/crypto.h>
 #include <openssl/x509.h>
 #include <openssl/pem.h>
 #include <openssl/ssl.h>
 #include <openssl/err.h>
+#endif
 
 #define PAM_SM_PASSWORD
 #include <security/_pam_macros.h>
@@ -140,6 +145,7 @@ __write_message (pam_handle_t *pamh, int msg_style,
 }
 
 #define HANDLE pam_handle_t *pamh,
+#define IAM_PAM_MODULE
 #define PRINTF __write_message
 #define ERR_HANDLE pamh, PAM_ERROR_MSG
 #define STD_HANDLE pamh, PAM_TEXT_INFO
@@ -193,6 +199,92 @@ read_string (pam_handle_t *pamh, int echo, const char *prompt,
   return PAM_SUCCESS;
 }
 
+#ifdef USE_GNUTLS
+static int
+handle_responses (pam_handle_t *pamh, gnutls_session ssl)
+{
+  response_header resp;
+  char retval = PAM_SUCCESS;
+  char *buf;
+
+  do
+    {
+      int ret;
+
+      if ((ret = gnutls_record_recv (ssl, &resp, sizeof (resp))) <= 0)
+	{
+	  if (ret == 0)
+	    __write_message (pamh, PAM_ERROR_MSG,
+			     _("error while reading request: %s"),
+			     _("Peer has closed the TLS connection"));
+	  else
+	    __write_message (pamh, PAM_ERROR_MSG,
+			     _("error while reading request: %s"),
+			     gnutls_strerror (ret));
+	  return PAM_SYSTEM_ERR;
+	}
+
+      buf = alloca (resp.data_len);
+      if ((ret = gnutls_record_recv (ssl, buf, resp.data_len)) <= 0)
+	{
+	  __write_message (pamh, PAM_ERROR_MSG,
+			   _("error while reading request data: %s"),
+			   gnutls_strerror (ret));
+	  return PAM_SYSTEM_ERR;
+	}
+
+      switch (resp.type)
+	{
+	case TEXT_INFO:
+	  __write_message (pamh, PAM_TEXT_INFO,
+			   "%s\n", buf);
+	  break;
+	case ERROR_MSG:
+	  __write_message (pamh, PAM_ERROR_MSG,
+			   "%s\n", buf);
+	  break;
+	case PROMPT_ECHO_OFF:
+	  {
+	    char *string = NULL;
+	    int nc = read_string (pamh, CONV_ECHO_OFF, buf, &string);
+	    if (nc < 0)
+	      retval = send_string (pamh, ssl, PAM_CONV_ERR, string);
+	    else
+	      retval = send_string (pamh, ssl, PAM_SUCCESS, string);
+	  }
+	  break;
+	case PROMPT_ECHO_ON:
+	  {
+	    char *string = NULL;
+	    int nc = read_string (pamh, CONV_ECHO_ON, buf, &string);
+	    if (nc < 0)
+	      retval = send_string (pamh, ssl, PAM_CONV_ERR, string);
+	    else
+	      retval = send_string (pamh, ssl, PAM_SUCCESS, string);
+	  }
+	  break;
+	case FINISH:
+	  retval = buf[0];
+	  break;
+	default:
+	  break;
+	}
+
+      if ((resp.type == PROMPT_ECHO_ON || resp.type == PROMPT_ECHO_OFF) &&
+	  retval != 0)
+	{
+	  char err_buf[256];
+
+	  PRINTF (ERR_HANDLE, _("Cannot send input back to server: %s\n"),
+		  strerror_r (errno, err_buf, sizeof (err_buf)));
+	  return PAM_SYSTEM_ERR;
+	}
+    }
+  while (resp.type != FINISH);
+
+  return retval;
+}
+#else
 static int
 handle_responses (pam_handle_t *pamh, SSL *ssl)
 {
@@ -282,6 +374,7 @@ handle_responses (pam_handle_t *pamh, SSL *ssl)
 
   return retval;
 }
+#endif
 
 static void
 parse_option (const char *argv, options_t *options)
@@ -337,8 +430,13 @@ pam_sm_chauthtok (pam_handle_t *pamh, int flags,
   char *user;
   int retval;
   int sock;
+#ifdef USE_GNUTLS
+  gnutls_session session;
+  gnutls_certificate_credentials xcred;
+#else
   SSL_CTX *ctx;
   SSL *ssl;
+#endif
 #ifdef USE_SLP
   int used_slp = 0;
 #endif
@@ -445,22 +543,47 @@ pam_sm_chauthtok (pam_handle_t *pamh, int flags,
     }
 
   /* Do SSL */
+#ifdef USE_GNUTLS
+  gnutls_global_init ();
+  /* Initialize TLS session. */
+  gnutls_init (&session, GNUTLS_CLIENT);
+  retval = start_ssl (pamh, sock, options->reqcert, options->verbose,
+		      session, &xcred);
+#else
   retval = start_ssl (pamh, sock, options->reqcert, options->verbose,
 		      &ctx, &ssl);
+#endif
+
   if (retval != 0)
     {
       free (options);
       return PAM_SYSTEM_ERR;
     }
 
+#ifdef USE_GNUTLS
+  if ((retval = start_request (pamh, session, user, 0)) == 0)
+    retval = handle_responses (pamh, session);
+  else
+    retval = PAM_SYSTEM_ERR;
+#else
   if ((retval = start_request (ssl, user, 0)) == 0)
     retval = handle_responses (pamh, ssl);
   else
     retval = PAM_SYSTEM_ERR;
+#endif
 
+#ifdef USE_GNUTLS
+  gnutls_bye (session, GNUTLS_SHUT_RDWR);
+  close (sock);
+  gnutls_deinit (session);
+  gnutls_certificate_free_credentials (xcred);
+  gnutls_global_deinit ();
+#else
   close (sock);
   SSL_free (ssl);
   SSL_CTX_free (ctx);
+#endif
+
   free (options);
 
   return retval;
