@@ -260,7 +260,13 @@ loop_over_passwd_file (int quiet)
   /* Open a temp passwd file */
   output_fd = mkstemp (outputname);
 #ifdef WITH_SELINUX
-  restore_default_context (prev_context);
+  if (restore_default_context (prev_context) < 0)
+    {
+      if (output_fd >= 0)
+	close (output_fd);
+      fclose (input);
+      return E_FAILURE;
+    }
 #endif
   if (output_fd == -1)
     {
@@ -522,7 +528,13 @@ loop_over_shadow_file (int quiet)
   /* Open a temp shadow file */
   output_fd = mkstemp (outputname);
 #ifdef WITH_SELINUX
-  restore_default_context (prev_context);
+  if (restore_default_context (prev_context) < 0)
+    {
+      if (output_fd >= 0)
+	close (output_fd);
+      fclose (input);
+      return E_FAILURE;
+    }
 #endif
   if (output_fd == -1)
     {
@@ -874,7 +886,14 @@ sort_passwd_file (void)
   /* Open a temp passwd file */
   newgf_fd = mkstemp (passwd_tmp);
 #ifdef WITH_SELINUX
-  restore_default_context (prev_context);
+  if (restore_default_context (prev_context) < 0)
+    {
+      if (newgf_fd >= 0)
+	close (newgf_fd);
+      fclose (oldgf);
+      retval = -1;
+      goto error_passwd;
+    }
 #endif
   if (newgf_fd == -1)
     {
