@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 Thorsten Kukuk
+/* Copyright (C) 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -156,7 +156,7 @@ main (int argc, char *argv[])
           print_help (program);
           return 0;
         case 'v':
-          print_version (program, "2004");
+          print_version (program, "2005");
           return 0;
         case 'u':
           print_usage (stdout, program);
@@ -203,9 +203,22 @@ main (int argc, char *argv[])
 		  return E_FAILURE;
 		}
 
-	      close (fd);
-	      chown (path, 0, shadow_grp ? shadow_grp->gr_gid : 0);
-	      chmod (path, S_IRUSR|S_IWUSR|S_IRGRP);
+	      if (chown (path, 0, shadow_grp ? shadow_grp->gr_gid : 0) < 0)
+		{
+		  fprintf (stderr,
+			   _("Cannot change owner/group for `%s': %s\n"),
+			   path, strerror (errno));
+		  unlink (path);
+		  return E_FAILURE;
+		}
+	      if (chmod (path, S_IRUSR|S_IWUSR|S_IRGRP) < 0)
+		{
+		  fprintf (stderr,
+			   _("Cannot change mode for `%s': %s\n"),
+			   path, strerror (errno));
+		  unlink (path);
+		  return E_FAILURE;
+		}
 	    }
 	  else
 	    {
@@ -221,7 +234,12 @@ main (int argc, char *argv[])
 	      fputs ("running out of memory!\n", stderr);
 	      return E_FAILURE;
 	    }
-	  link (path, tmpshadow);
+	  if (link (path, tmpshadow) < 0)
+	    {
+	      fprintf (stderr, _("Cannot create backup file `%s': %m\n"),
+		       tmpshadow);
+	      return E_FAILURE;
+	    }
 	}
       free (path);
 
@@ -236,7 +254,13 @@ main (int argc, char *argv[])
 	  fputs ("running out of memory!\n", stderr);
 	  return E_FAILURE;
 	}
-      link (path, tmppasswd);
+      if (link (path, tmppasswd) < 0)
+	{
+	  fprintf (stderr, _("Cannot create backup file `%s': %m\n"),
+		   tmppasswd);
+	  return E_FAILURE;
+	}
+
       free (path);
     }
 
@@ -391,7 +415,13 @@ main (int argc, char *argv[])
 	  return E_FAILURE;
 	}
       unlink (oldshadow);
-      rename (tmpshadow, oldshadow);
+      if (rename (tmpshadow, oldshadow) < 0)
+	{
+	  fprintf (stderr,
+		   _("Error while renaming temporary shadow file: %m\n"));
+	  unlink (tmpshadow);
+	  return E_FAILURE;
+	}
       free (oldshadow);
       free (tmpshadow);
     }
@@ -405,10 +435,17 @@ main (int argc, char *argv[])
       if (asprintf (&oldpasswd, "%s/passwd.old", files_etc_dir) < 0)
 	{
 	  fputs ("running out of memory!\n", stderr);
+	  unlink (tmppasswd);
 	  return E_FAILURE;
 	}
       unlink (oldpasswd);
-      rename (tmppasswd, oldpasswd);
+      if (rename (tmppasswd, oldpasswd) < 0)
+	{
+	  fprintf (stderr,
+		   _("Error while renaming temporary password file: %m\n"));
+	  unlink (tmppasswd);
+	  return E_FAILURE;
+	}
       free (oldpasswd);
       free (tmppasswd);
     }
