@@ -352,8 +352,9 @@ load_defaults (const char *configfile, struct default_t *data)
 		  if (((expire = strtol (&cp[7], &ep, 10)) == 0 && *ep) ||
 		      expire < -1)
 		    {
-		      fprintf (stderr, _("%s: Expiredate `%s' is no date and \
-no integer value >= -1 in %s.\n"), program, &cp[7], configfile);
+		      fprintf (stderr,
+			       _("%s: Expiredate `%s' is no date and no integer value >= -1 in %s.\n"),
+			       program, &cp[7], configfile);
 		      ++errors;
 		    }
 		}
@@ -1215,8 +1216,9 @@ main (int argc, char **argv)
 		  if (((expire = strtol (optarg, &cp, 10)) == 0 && *cp) ||
 		      expire < -1)
 		    {
-		      fprintf (stderr, _("%s: Expiredate `%s' is no date\
- and no integer value >= -1.\n"), program, optarg);
+		      fprintf (stderr,
+			       _("%s: Expiredate `%s' is no date and no integer value >= -1.\n"),
+			       program, optarg);
 		      return E_BAD_ARG;
 		    }
 		}
@@ -1330,7 +1332,7 @@ main (int argc, char **argv)
 #endif
           else
             {
-              fprintf (stderr, _("Service `%s' not supported\n"), optarg);
+              fprintf (stderr, _("Service `%s' not supported.\n"), optarg);
               print_usage (stderr, program);
               return E_BAD_ARG;
             }
@@ -1690,7 +1692,7 @@ main (int argc, char **argv)
 	    {
 	      if (use_service == NULL)
 		fprintf (stderr,
-			 _("%s: ERROR: cannot find group `%s' anymore!.\n"),
+			 _("%s: ERROR: Cannot find group `%s' anymore!\n"),
 			 program, new_groups[i]);
 	      else
 		fprintf (stderr,
@@ -1709,7 +1711,8 @@ main (int argc, char **argv)
 		      binddn = get_caller_dn ();
 		      if (binddn == NULL)
 			{
-			  fprintf (stderr, _("%s: Cannot add user to groups stored in LDAP database without DN.\n"),
+			  fprintf (stderr,
+				   _("%s: Cannot add user to groups stored in LDAP database without DN.\n"),
 				   program);
 			}
 		    }
