@@ -165,7 +165,7 @@ convert_grpopt_to_name (const char *arg, char **grouplist, gid_t *groupid,
 	  if (use_service)
 	    {
 	      fprintf (stderr,
-		       _("%s: group `%u' not found in service `%s'.\n"),
+		       _("%s: Group `%u' not found in service `%s'.\n"),
 		       program, gid, use_service);
 	      return E_NOTFOUND;
 	    }
@@ -184,7 +184,7 @@ convert_grpopt_to_name (const char *arg, char **grouplist, gid_t *groupid,
 	  if (use_service)
 	    {
 	      fprintf (stderr,
-		       _("%s: group `%s' not found in service `%s'.\n"),
+		       _("%s: Group `%s' not found in service `%s'.\n"),
 		       program, utf8_to_locale (arg), use_service);
 	      return E_NOTFOUND;
 	    }
@@ -402,7 +402,7 @@ rename_in_secondary_groups (user_t *pw_data, int have_extrapath)
       if (gr_data == NULL || gr_data->service == S_NONE)
         {
           fprintf (stderr,
-                   _("%s: ERROR: cannot find group `%s' anymore!.\n"),
+                   _("%s: ERROR: Cannot find group `%s' anymore!\n"),
                    program, utf8_to_locale (item->value));
           if (retval == E_SUCCESS)
             retval = E_NOTFOUND;
@@ -525,7 +525,7 @@ move_home_directory (const char *oldhome, const char *newhome)
 	      if (mkdir (path, 0) != 0)
 		{
 		  fprintf (stderr,
-			   _("%s: cannot create directory `%s'.\n"),
+			   _("%s: Cannot create directory `%s'.\n"),
 			   program, path);
 		  return E_HOMEDIR;
 		}
@@ -548,23 +548,29 @@ move_home_directory (const char *oldhome, const char *newhome)
 	{
 	  if (mkdir (newhome, st.st_mode & 0777))
 	    {
-	      fprintf (stderr, _("%s: can't create %s\n"),
+	      fprintf (stderr, _("%s: Can't create %s.\n"),
 		       program, newhome);
 	      return E_HOMEDIR;
 	    }
 	  if (chown (newhome, st.st_uid, st.st_gid))
 	    {
-	      fprintf (stderr, _("%s: can't chown %s\n"),
+	      fprintf (stderr, _("%s: Can't chown %s.\n"),
 		       program, newhome);
 	      rmdir (newhome);
 	      return E_HOMEDIR;
 	    }
-	  copy_dir_rec (oldhome, newhome, 1, 0, 0);
-	  remove_dir_rec (oldhome);
+	  if (copy_dir_rec (oldhome, newhome, 1, 0, 0) == 0)
+	    remove_dir_rec (oldhome); /* only remove if no error occured. */
+	  else
+	    {
+	      fprintf (stderr, _("%s: Cannot copy directory %s to %s.\n"),
+		       program, oldhome, newhome);
+	      return E_HOMEDIR;
+	    }
 	}
       else
 	{
-	  fprintf (stderr, _("%s: cannot rename directory %s to %s\n"),
+	  fprintf (stderr, _("%s: Cannot rename directory %s to %s.\n"),
 		   program, oldhome, newhome);
 	  return E_HOMEDIR;
 	}
@@ -634,7 +640,7 @@ remove_from_secondary_groups (user_t *pw_data, int have_extrapath,
       if (gr_data == NULL || gr_data->service == S_NONE)
         {
           fprintf (stderr,
-                   _("%s: ERROR: cannot find group `%s' anymore!.\n"),
+                   _("%s: ERROR: Cannot find group `%s' anymore!\n"),
                    program, utf8_to_locale (item->value));
           if (retval == E_SUCCESS)
             retval = E_NOTFOUND;
@@ -828,8 +834,9 @@ main (int argc, char **argv)
 		  if (((expire = strtol (optarg, &cp, 10)) == 0 && *cp) ||
 		      expire < -1)
 		    {
-		      fprintf (stderr, _("%s: Expiredate `%s' is no date\
- and no integer value >= -1.\n"), program, optarg);
+		      fprintf (stderr,
+			       _("%s: Expiredate `%s' is no date and no integer value >= -1.\n"),
+			       program, optarg);
 		      return E_BAD_ARG;
 		    }
 		}
@@ -970,7 +977,7 @@ main (int argc, char **argv)
 #endif
 	  else
 	    {
-	      fprintf (stderr, _("Service `%s' not supported\n"), optarg);
+	      fprintf (stderr, _("Service `%s' not supported.\n"), optarg);
 	      print_usage (stderr, program);
 	      return E_BAD_ARG;
 	    }
@@ -1246,7 +1253,7 @@ main (int argc, char **argv)
     {
       sec_log (program, MSG_ACCOUNT_IN_USE, modify_account,
 	       pw_data->pw.pw_uid, getuid ());
-      fprintf (stderr, _("%s: account `%s' is currently in use.\n"),
+      fprintf (stderr, _("%s: Account `%s' is currently in use.\n"),
 	       program, utf8_to_locale (modify_account));
       return E_USER_BUSY;
     }
@@ -1343,7 +1350,7 @@ main (int argc, char **argv)
 	  else
 	    {
 	      fprintf (stderr,
-		       _("%s: Shadow passwords required for -e and -f\n"),
+		       _("%s: Shadow passwords required for -e and -f.\n"),
 		       program);
 	      return E_NO_SHADOW;
 	    }
@@ -1358,8 +1365,7 @@ main (int argc, char **argv)
 	      if (binddn == NULL)
 		{
 		  fprintf (stderr,
-			   _
-			   ("%s: Cannot modify user in LDAP database without DN.\n"),
+			   _("%s: Cannot modify user in LDAP database without DN.\n"),
 			   program);
 		}
 	      else
@@ -1479,12 +1485,11 @@ main (int argc, char **argv)
 	    {
 	      if (use_service == NULL)
 		fprintf (stderr,
-			 _("%s: ERROR: cannot find group `%s' anymore!.\n"),
+			 _("%s: ERROR: Cannot find group `%s' anymore!\n"),
 			 program, utf8_to_locale (new_groups[i]));
 	      else
 		fprintf (stderr,
-			 _
-			 ("%s: Cannot find group `%s' in service `%s', ignored.\n"),
+			 _("%s: Cannot find group `%s' in service `%s', ignored.\n"),
 			 program, utf8_to_locale (new_groups[i]), use_service);
 	      retval = E_NOTFOUND;
 	    }
@@ -1500,8 +1505,7 @@ main (int argc, char **argv)
 		      if (binddn == NULL)
 			{
 			  fprintf (stderr,
-				   _
-				   ("%s: Cannot add user to groups stored in LDAP database without DN.\n"),
+				   _("%s: Cannot add user to groups stored in LDAP database without DN.\n"),
 				   program);
 			}
 		    }
@@ -1581,12 +1585,11 @@ main (int argc, char **argv)
 	    {
 	      if (use_service == NULL)
 		fprintf (stderr,
-			 _("%s: ERROR: cannot find group `%s' anymore!.\n"),
+			 _("%s: ERROR: cannot find group `%s' anymore!\n"),
 			 program, utf8_to_locale (del_groups[i]));
 	      else
 		fprintf (stderr,
-			 _
-			 ("%s: Cannot find group `%s' in service `%s', ignored.\n"),
+			 _("%s: Cannot find group `%s' in service `%s', ignored.\n"),
 			 program, utf8_to_locale (del_groups[i]), use_service);
 	      retval = E_NOTFOUND;
 	    }
@@ -1602,8 +1605,7 @@ main (int argc, char **argv)
 		      if (binddn == NULL)
 			{
 			  fprintf (stderr,
-				   _
-				   ("%s: Cannot remove user from groups stored in LDAP database without DN.\n"),
+				   _("%s: Cannot remove user from groups stored in LDAP database without DN.\n"),
 				   program);
 			}
 		    }
