@@ -182,7 +182,14 @@ edit (const char *file, const char *program, int shadow)
 #endif
   new_fd = mkstemp (tmpname);
 #ifdef WITH_SELINUX
-  restore_default_context (prev_context);
+  if (restore_default_context (prev_context) < 0)
+    {
+      if (new_fd >= 0)
+	close (new_fd);
+      ulckpwdf ();
+      free (tmpname);
+      return E_FAILURE;
+    }
 #endif
   if (new_fd == -1)
     {
